@@ -1,6 +1,6 @@
 package EntityModel::Class::Accessor::Array;
 BEGIN {
-  $EntityModel::Class::Accessor::Array::VERSION = '0.002';
+  $EntityModel::Class::Accessor::Array::VERSION = '0.003';
 }
 use strict;
 use warnings FATAL => 'all', NONFATAL => 'redefine';
@@ -14,17 +14,33 @@ use Class::ISA;
 
 my %watcher;
 
-=pod
+=head1 NAME
+
+EntityModel::Class::Accessor::Array - generic class accessor for arrays
+
+=head1 VERSION
+
+version 0.003
+
+=head1 SYNOPSIS
+
+See L<EntityModel::Class>.
+
+=head1 DESCRIPTION
+
+See L<EntityModel::Class>.
+
+=head1 METHODS
 
 =cut
 
-=head2 C<methodList>
+=head2 method_list
 
-Returns a hash of method definitions.
+Returns the method definition to add to the class.
 
 =cut
 
-sub methodList {
+sub method_list {
 	my ($class, %opt) = @_;
 	my $k = $opt{k};
 	return sub {
@@ -36,7 +52,7 @@ sub methodList {
 		$self->{$k} ||= [ ];
 		my @watchers = map { @{ $watcher{$_}->{$k} // [] } } Class::ISA::self_and_super_path(ref $self);
 		logDebug("Watcher for [%s] method [%s] has %d entries", ref $self, $k, scalar @watchers);
-		return new EntityModel::Array::($self->{$k},
+		return EntityModel::Array->new($self->{$k},
 			  (@watchers)
 			? (onchange => sub {
 				logDebug("Check [%s] for [%s]", ref $self, $k);
@@ -47,7 +63,13 @@ sub methodList {
 	};
 }
 
-sub addWatcher {
+=head2 add_watcher
+
+Add this to the list of watchers for the class.
+
+=cut
+
+sub add_watcher {
 	my ($class, $pkg, $meth, @sub) = @_;
 	logDebug("Watching [%s] for [%s]", $meth, $pkg);
 	push @{$watcher{$pkg}->{$meth}}, @sub;
@@ -55,3 +77,13 @@ sub addWatcher {
 }
 
 1;
+
+__END__
+
+=head1 AUTHOR
+
+Tom Molesworth <cpan@entitymodel.com>
+
+=head1 LICENSE
+
+Copyright Tom Molesworth 2008-2011. Licensed under the same terms as Perl itself.
\ No newline at end of file
